/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "qsnd/mixer_simple_filter.hpp"
#include <QString>
#include <vector>

namespace QSnd
{

/// @brief Mixer_Simple_Filter
///
/// Filters mixer elements from a list by their name
///
class Mixer_Simple_Filter_Name : public ::QSnd::Mixer_Simple_Filter
{
  // Public methods
  public:
  // Construction

  Mixer_Simple_Filter_Name ( bool blacklist_n = true );

  virtual ~Mixer_Simple_Filter_Name () override;

  // Blacklist

  /// @brief true if this is a blacklist. false if it is a whitelist.
  ///
  bool
  blacklist () const
  {
    return _blacklist;
  }

  void
  set_blacklist ( bool flag_n );

  // Names

  const ::std::vector< QString > &
  names () const
  {
    return _names;
  }

  void
  append_name ( const QString & name_n );

  void
  append_names ( const ::std::vector< QString > & names_n );

  // Filter

  ::std::size_t
  filter ( Element_Vector & accept_n, Element_Vector & drop_n ) override;

  // Private attributes
  private:
  ::std::vector< QString > _names;
  bool _blacklist = true;
};

} // namespace QSnd
