/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "qsnd/alsa.hpp"
#include "qsnd/pcm_subdevice_info.hpp"
#include <QString>
#include <memory>
#include <vector>

namespace QSnd
{

/// @brief PCM_Subdevices_Info
///
class PCM_Subdevices_Info
{
  // Public methods
  public:
  PCM_Subdevices_Info ();

  ~PCM_Subdevices_Info ();

  unsigned int
  stream_dir () const
  {
    return _stream_dir;
  }

  unsigned int
  num_subdevices () const
  {
    return _num_sdevs;
  }

  unsigned int
  num_subdevices_avail () const
  {
    return _num_sdevs_avail;
  }

  const PCM_Subdevice_Info *
  subdevice_info ( ::std::size_t idx_n ) const
  {
    return _sdevs_info[ idx_n ].get ();
  }

  void
  clear ();

  int
  acquire_subdevices ( snd_ctl_t * snd_ctl_handle_n,
                       int dev_idx_n,
                       unsigned int stream_dir_n );

  // Private attributes
  private:
  unsigned int _stream_dir = 0;
  unsigned int _num_sdevs = 0;
  unsigned int _num_sdevs_avail = 0;

  ::std::vector< ::std::unique_ptr< ::QSnd::PCM_Subdevice_Info > > _sdevs_info;
};

} // namespace QSnd
