/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "dpe/image_allocator.hpp"
#include "dpe/image_request.hpp"
#include "dpe/image_set_group.hpp"
#include <memory>

// Forward declaration
class QWidget;

namespace Wdg
{

/// @brief DS_Imaging
///
class DS_Imaging
{
  // Public methods
  public:
  // -- Construction

  DS_Imaging ( unsigned int num_image_groups_n,
               ::dpe::Image_Allocator * alloc_n = nullptr );

  ~DS_Imaging ();

  // -- Image allocator

  ::dpe::Image_Allocator *
  image_alloc () const
  {
    return _image_alloc;
  }

  void
  set_image_alloc ( ::dpe::Image_Allocator * alloc_n );

  // -- Images

  ::dpe::Image_Set_Group &
  images ()
  {
    return _images;
  }

  ::dpe::Image_Request *
  image_request () const
  {
    return _image_request.get ();
  }

  void
  send_request ()
  {
    _request_sent = true;
    _image_alloc->send_request ( image_request () );
  }

  void
  wait_for_request ()
  {
    if ( _request_sent ) {
      _request_sent = false;
      image_request ()->wait_for_finish ();
    }
  }

  void
  set_images_variant_id ( unsigned int variant_n );

  void
  set_images_style_id ( unsigned int style_n );

  void
  set_images_style_sub_id ( unsigned int style_n );

  static unsigned int
  style_sub_id ( QWidget * wdg_n );

  // Private attributes
  private:
  ::dpe::Image_Set_Group _images;
  ::dpe::Image_Allocator * _image_alloc = nullptr;
  ::std::unique_ptr< ::dpe::Image_Request > _image_request;
  bool _request_sent = false;
};

} // namespace Wdg
