/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "wdg/ds_widget_types.hpp"
#include <QHash>
#include <QPalette>

namespace Wdg
{

/// @brief DS_Widget_Style_Db
///
class DS_Widget_Style_Db
{
  // Public typedefs
  public:
  enum STYLES
  {
    ST_NORMAL = 0,
    ST_USER = 32 // User defined style should start here
  };

  // Public methods
  public:
  // -- Construction

  DS_Widget_Style_Db ();

  ~DS_Widget_Style_Db ();

  // -- Palette

  QPalette
  palette ( unsigned int style_id_n ) const
  {
    return palettes.value ( style_id_n );
  }

  const QColor &
  color ( unsigned int style_id_n, QPalette::ColorRole role_n ) const
  {
    return palette ( style_id_n ).color ( role_n );
  }

  const QColor &
  color ( unsigned int style_id_n,
          QPalette::ColorGroup group_n,
          QPalette::ColorRole role_n ) const
  {
    return palette ( style_id_n ).color ( group_n, role_n );
  }

  QPalette::ColorGroup
  color_group ( ::Wdg::DS_Widget_State state_n ) const
  {
    QPalette::ColorGroup res;
    switch ( state_n ) {
    case ::Wdg::ST_DISABLED:
      res = QPalette::Disabled;
      break;
    case ::Wdg::ST_INACTIVE:
      res = QPalette::Inactive;
      break;
    default:
      res = QPalette::Normal;
    }
    return res;
  }

  QPalette::ColorGroup
  color_group ( unsigned int state_n ) const
  {
    return color_group ( (::Wdg::DS_Widget_State)state_n );
  }

  // Public attributes
  public:
  QHash< unsigned int, QPalette > palettes;
};

} // namespace Wdg
