/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "wdg/pad_focus_info.hpp"
#include <QPen>
#include <QWidget>
#include <vector>

// Forward declaration
namespace Wdg
{
class Pad_Proxies_Group;
class Switches_Pad_Widgets_Group;
} // namespace Wdg

namespace Wdg
{

/// @brief Switches_Pad
///
class Switches_Pad : public QWidget
{
  Q_OBJECT

  // Public methods
  public:
  // -- Construction

  Switches_Pad ( QWidget * parent_n = nullptr );

  ~Switches_Pad ();

  void
  set_viewport_geometry ( const QRect & rect_n );

  // -- Proxies groups

  const ::std::vector< ::Wdg::Pad_Proxies_Group * > &
  proxies_groups () const
  {
    return _proxies_groups;
  }

  void
  set_proxies_groups (
      const ::std::vector< ::Wdg::Pad_Proxies_Group * > & groups_n );

  void
  clear_proxies_groups ();

  // -- Proxies groups access

  ::std::size_t
  num_proxies_groups () const
  {
    return _proxies_groups.size ();
  }

  ::Wdg::Pad_Proxies_Group *
  proxies_group ( ::std::size_t idx_n )
  {
    return _proxies_groups[ idx_n ];
  }

  // -- Focus item getting / setting

  const ::Wdg::Pad_Focus_Info &
  focus_info ()
  {
    return _focus_info;
  }

  // -- Event handling

  bool
  event ( QEvent * event_n ) override;

  // Public slots
  public:
  Q_SLOT
  void
  set_focus_proxy ( unsigned int proxies_group_idx_n );

  Q_SLOT
  void
  set_focus_proxy ( unsigned int proxies_group_idx_n,
                    unsigned int proxy_idx_n );

  // Public signals

  Q_SIGNAL
  void
  sig_focus_changed ();

  // Protected methods
  protected:
  void
  clear_widgets_groups ();

  void
  create_widgets_groups ();

  void
  update_colors ();

  // Private attributes
  private:
  ::std::vector< ::Wdg::Pad_Proxies_Group * > _proxies_groups;
  ::std::vector< ::Wdg::Switches_Pad_Widgets_Group * > _widgets_groups;

  QRect _viewport;
  Pad_Focus_Info _focus_info;

  QPen _stem_pen;
};

} // namespace Wdg
